@@ -1,7 +1,9 @@
 import os
 import tempfile
 import subprocess
+import sys
 from lxml import etree
+from pprint import PrettyPrinter
 
 
 def save(text):
@@ -24,6 +26,21 @@ def xmlformat(text, encoding='utf-8'):
     tree = etree.fromstring(text)
     return etree.tostring(tree, encoding=encoding, pretty_print=True)
 
+def pprint(obj, stream=None, indent=1, width=80, depth=None):
+
+    class _PrettyPrinter(PrettyPrinter):
+        def format(self, *args, **kwargs):
+            repr, readable, recursive = PrettyPrinter.format(self, *args, **kwargs)
+            if repr:
+                if repr[0] in ('"', "'"):
+                    repr = repr.decode('string_escape')
+                elif repr[0:2] in ("u'", 'u"'):
+                    repr = repr.decode('unicode_escape').encode(sys.stdout.encoding)
+            return repr, readable, recursive
+
+    printer = _PrettyPrinter(stream=stream, indent=indent, width=width, depth=depth)
+    printer.pprint(obj)
+
 def uprint(value):
     if hasattr(value, '__iter__'):
         print _print(value)
